@@ -1,9 +1,9 @@
 const char * const rcsid_common_commands_c =
-    "$Id: commands.c 14099 2010-11-15 07:21:33Z mwedel $";
+    "$Id: commands.c 15869 2011-11-21 07:03:36Z mwedel $";
 /*
     Crossfire client, a client program for the crossfire program.
 
-    Copyright (C) 2001,2010 Mark Wedel & Crossfire Development Team
+    Copyright (C) 2001-2011 Mark Wedel & Crossfire Development Team
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -724,7 +724,9 @@ static void get_skill_info(char *data, int len) {
         sn++;
         val = atoi(cp);
         val -= CS_STAT_SKILLINFO;
-        if (val < 0 || val> CS_NUM_SKILLS) {
+
+        /* skill_names[MAX_SKILL] is the declaration, so check against that */
+        if (val < 0 || val >= MAX_SKILL) {
             LOG(LOG_WARNING, "common::get_skill_info", "invalid skill number %d", val);
             return;
         }
@@ -1336,35 +1338,6 @@ void StatsCmd(unsigned char *data, int len) {
             case CS_STAT_FLAGS: cpl.stats.flags = GetShort_String(data+i); i += 2; break;
             case CS_STAT_WEIGHT_LIM:set_weight_limit(cpl.stats.weight_limit = GetInt_String(data+i)); i += 4; break;
 
-                /* Skill experience handling */
-                /* We make the assumption based on current bindings in the
-                 * protocol that these skip 2 values and are otherwise in
-                 * order.
-                 */
-            case CS_STAT_SKILLEXP_AGILITY:
-            case CS_STAT_SKILLEXP_PERSONAL:
-            case CS_STAT_SKILLEXP_MENTAL:
-            case CS_STAT_SKILLEXP_PHYSIQUE:
-            case CS_STAT_SKILLEXP_MAGIC:
-            case CS_STAT_SKILLEXP_WISDOM:
-                {
-                    int skill_id = (c-CS_STAT_SKILLEXP_START)/2;
-                    cpl.stats.skill_exp[skill_id] = GetInt_String(data+i);
-                    use_skill(skill_id);
-                    i += 4;
-                }
-                break;
-
-            case CS_STAT_SKILLEXP_AGLEVEL:
-            case CS_STAT_SKILLEXP_PELEVEL:
-            case CS_STAT_SKILLEXP_MELEVEL:
-            case CS_STAT_SKILLEXP_PHLEVEL:
-            case CS_STAT_SKILLEXP_MALEVEL:
-            case CS_STAT_SKILLEXP_WILEVEL:
-                cpl.stats.skill_level[(c-CS_STAT_SKILLEXP_START-1)/2] = GetShort_String(data+i);
-                i += 2;
-                break;
-
             case CS_STAT_RANGE: {
                 int rlen = data[i++];
                 strncpy(cpl.range, (const char*)data+i, rlen);
@@ -2253,6 +2226,9 @@ void FailureCmd(char *buf, int len) {
     else if (!strcmp(buf,"createplayer")) {
         create_new_character_failure(cp);
     }
+    else if (!strcmp(buf, "accountpw")) {
+        account_change_password_failure(cp);
+    }
     else
         /* This really is an error - if this happens it menas the server
          * failed to process a request that the client made - the client
