@@ -1,9 +1,9 @@
 const char * const rcsid_common_item_c =
-    "$Id$";
+    "$Id: item.c 12356 2010-01-20 08:07:04Z mwedel $";
 /*
     Crossfire client, a client program for the crossfire program.
 
-    Copyright (C) 2001 Mark Wedel & Crossfire Development Team
+    Copyright (C) 2001,2010 Mark Wedel & Crossfire Development Team
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,11 +22,15 @@ const char * const rcsid_common_item_c =
     The author can be reached via e-mail to crossfire-devel@real-time.com
 */
 
+/**
+ * @file common/item.c
+ * Provides functions that process items in various ways.
+ */
 
 #include <ctype.h>      /* needed for isdigit */
 #include <client.h>
 #include <item.h>
-#include <newclient.h>
+#include <shared/newclient.h>
 #include <external.h>
 #include <script.h>
 
@@ -668,14 +672,14 @@ void print_inventory(item *op) {
     if (l == 0) {
         snprintf(buf, sizeof(buf), "%s's inventory (%d):", op->d_name, op->tag);
         snprintf(buf2, sizeof(buf2), "%-*s%6.1f kg", info_width-10, buf, op->weight);
-        draw_info(buf2,NDI_BLACK);
+        draw_ext_info(NDI_BLACK, MSG_TYPE_CLIENT, MSG_TYPE_CLIENT_DEBUG, buf2);
     }
 
     l += 2;
     for (tmp = op->inv; tmp; tmp = tmp->next) {
         snprintf(buf, sizeof(buf), "%*s- %d %s%s (%d)", l-2, "", tmp->nrof, tmp->d_name, tmp->flags, tmp->tag);
         snprintf(buf2, sizeof(buf2), "%-*s%6.1f kg", info_width-8-l, buf, tmp->nrof*tmp->weight);
-        draw_info(buf2,NDI_BLACK);
+        draw_ext_info(NDI_BLACK, MSG_TYPE_CLIENT, MSG_TYPE_CLIENT_DEBUG, buf2);
         if (tmp->inv) {
             print_inventory(tmp);
         }
@@ -757,10 +761,6 @@ void inscribe_magical_scroll(item *scroll, Spell *spell) {
     SockList sl;
     uint8 buf[MAX_BUF];
 
-    if (command_inscribe == 0) {
-        LOG(LOG_WARNING, "common::inscribe_magical_scroll", "Called when server doesn't handle inscribe command.");
-        return;
-    }
     snprintf((char*)buf, sizeof(buf), "inscribe 0 %d %d", scroll->tag, spell->tag);
     script_monitor_str((char*)buf);
     SockList_Init(&sl, buf);
