@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: mapdata.h 12149 2009-08-20 02:11:28Z kbulgrien $ */
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -21,12 +21,16 @@
     The author can be reached via e-mail to crossfire-devel@real-time.com
 */
 
+/**
+ * @file common/mapdata.h
+ *
+ */
+
 #ifndef MAP_H
 #define MAP_H
 
 #include "client-types.h"
 
-
 /** The protocol supports 10 layers, so set MAXLAYERS accordingly.
  */
 #define MAXLAYERS 10
@@ -77,7 +81,7 @@ struct MapCell
     struct MapCellLayer heads[MAXLAYERS];
     struct MapCellLayer tails[MAXLAYERS];
     uint16 smooth[MAXLAYERS];
-    uint8 darkness;         /* darkness: 0=fully illuminated, 255=pitch blank */
+    uint8 darkness;         /* darkness: 0=fully illuminated, 255=pitch black */
     uint8 need_update:1;    /* set if tile should be redrawn */
     uint8 have_darkness:1;  /* set if darkness information was set */
     uint8 need_resmooth:1;  /* same has need update but for smoothing only */
