@@ -1,5 +1,5 @@
 const char * const rcsid_common_metaserver_c =
-    "$Id: metaserver.c 13981 2010-10-09 21:43:20Z anmaster $";
+    "$Id: metaserver.c 15072 2011-09-10 10:59:18Z ryo_saeba $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -49,7 +49,6 @@ const char * const rcsid_common_metaserver_c =
 
 #ifdef HAVE_CURL_CURL_H
 #include <curl/curl.h>
-#include <curl/types.h>
 #include <curl/easy.h>
 #endif
 
@@ -312,7 +311,8 @@ size_t metaserver2_writer(void *ptr, size_t size, size_t nmemb, void *data)
      */
     memcpy(inbuf, leftover, strlen(leftover));
     memcpy(inbuf+strlen(leftover), ptr, realsize);
-    inbuf[realsize] = 0;
+    inbuf[strlen(leftover)+realsize] = 0;
+    leftover[0] =0;
 
     /* Processing this block of data shouldn't take very long, even on
      * slow machines, so putting the lock here, instead of each time
