@@ -1,5 +1,5 @@
 /* char *rcsid_common_metaserver_h =
- *   "$Id: metaserver.h 12875 2010-04-09 07:04:28Z mwedel $";
+ *   "$Id: metaserver.h 13043 2010-04-30 01:05:36Z kbulgrien $";
  */
 
 /*
@@ -87,3 +87,8 @@ extern int cached_servers_num;
 extern char* cached_servers_name[ CACHED_SERVERS_MAX ];
 extern char* cached_servers_ip[ CACHED_SERVERS_MAX ];
 extern const char* cached_server_file;
+
+/* Used by GTK-V2 client to maintain servers.cache */
+extern
+void metaserver_update_cache(const char *server_name, const char *server_ip);
+
