@@ -1,5 +1,5 @@
 const char * const rcsid_common_misc_c =
-    "$Id: misc.c 12149 2009-08-20 02:11:28Z kbulgrien $";
+    "$Id: misc.c 13982 2010-10-09 22:41:04Z anmaster $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -41,11 +41,62 @@ const char * const rcsid_common_misc_c =
 #include <io.h>
 #endif
 
-/*
+/**
+ * Convert a buffer of a specified maximum size by replacing token characters
+ * with a provided string.  Given a buffered template string "/input/to/edit",
+ * the maximum size of the buffer, a token '/', and a replacement string ":",
+ * the input string is transformed to ":input:to:edit".  If the replacement
+ * string is empty, the token characters are simply removed.  The template is
+ * processed from left to right, replacing token characters as they are found.
+ * Replacement strings are always inserted whole.  If token replacement would
+ * overflow the size of the conversion buffer, the token is not replaced, and
+ * the remaining portion of the input string is appended after truncating it
+ * as required to avoid overfilling the buffer.
+ * @param buffer      A string to perform a find and replace operation on.
+ * @param buffer_size Allocated buffer size (used to avoid buffer overflow).
+ * @param find        A token character to find and replace in the buffer.
+ * @param replace     A string that is to replace each token in the buffer.
+ */
+void replace_chars_with_string(char*        buffer,
+                               const uint16 buffer_size,
+                               const char   find,
+                               const char*  replace      ) {
+
+    uint16 buffer_len, expand, i, replace_len, replace_limit, template_len;
+    char*  template;
+
+    replace_limit = buffer_size - 1;
+    replace_len = strlen(replace);
+    template_len = strlen(buffer);
+    template = strdup(buffer);
+    buffer[0] = '\0';
+
+    buffer_len = 0;
+    for (i = 0; i <= template_len; i++)
+    {
+        expand = buffer_len + replace_len < replace_limit ? replace_len : 1;
+        if (expand == 1 && buffer_len == replace_limit)
+        {
+            break;
+        }
+        if ((template[i] != find) || ((expand == 1) && (replace_len > 1)))
+        {
+            buffer[buffer_len++] = template[i];
+            buffer[buffer_len] = '\0';
+        }
+        else
+        {
+            strcat(buffer, replace);
+            buffer_len += replace_len;
+        }
+    }
+    free(template);
+}
+
+/**
  * Verifies that the directory exists, creates it if necessary
  * Returns -1 on failure
  */
-
 int make_path_to_dir (char *directory)
 {
     char buf[MAX_BUF], *cp = buf;
@@ -82,11 +133,9 @@ int make_path_to_dir (char *directory)
     return 0;
 }
 
-
-/*
+/**
  * If any directories in the given path doesn't exist, they are created.
  */
-
 int make_path_to_file (char *filename)
 {
     char buf[MAX_BUF], *cp = buf;
@@ -100,10 +149,12 @@ int make_path_to_file (char *filename)
 	if (stat (buf, &statbuf) || !S_ISDIR (statbuf.st_mode)) {
 #ifdef WIN32
 	    if (mkdir (buf)) {
+                LOG(LOG_ERROR, "misc.c::make_path_to_file",
+                    "Couldn't make path to file: %s", strerror(errno));
 #else
 	    if (mkdir (buf, 0777)) {
-#endif
 		perror ("Couldn't make path to file");
+#endif
 		return -1;
 	    }
 	}
@@ -111,32 +162,40 @@ int make_path_to_file (char *filename)
     }
     return 0;
 }
-/*
+
+/**
  * A replacement of strdup(), since it's not defined at some
  * unix variants.
  */
-
 char *strdup_local(const char *str) {
   char *c=(char *)malloc(sizeof(char)*strlen(str)+1);
   strcpy(c,str);
   return c;
 }
 
-
 /* logging stuff */
 LogEntry* LogFirst=NULL;
 LogEntry* LogLast=NULL;
 int logcount=0;
 LogListener loglist=NULL;
+
+/**
+ *
+ */
 int setLogListener(LogListener li){
     if (loglist)
         return 0;
     loglist=li;
     return 1;
 }
+
+/**
+ *
+ */
 void clearLogListener(void) {
     loglist=NULL;
 }
+
 static const char *const LogLevelTexts[] = {
     " DEBUG  ",
     "  INFO  ",
@@ -145,9 +204,17 @@ static const char *const LogLevelTexts[] = {
     "CRITICAL",
     "UNKNOWN ",
 };
+
+/**
+ *
+ */
 static const char *getLogLevelText(LogLevel level) {
     return LogLevelTexts[level>LOG_CRITICAL?LOG_CRITICAL+1:level];
 }
+
+/**
+ *
+ */
 char *getLogTextRaw(LogLevel level, const char *origin, const char *message) {
     static char mybuf[20480];
     mybuf[0]='\0';
@@ -155,20 +222,22 @@ char *getLogTextRaw(LogLevel level, const char *origin, const char *message) {
     return mybuf;
 }
 
+/**
+ *
+ */
 char *getLogText(const LogEntry *le) {
     return getLogTextRaw(le->level,le->origin,le->message);
 }
-/*
+
+int MINLOG=MINLOGLEVEL;
+
+/**
  * Logs a message to stderr and save it in memory.
  * Or discards the message if it is of no importanse, and none have
  * asked to hear messages of that logLevel.
  *
  * See client.h for possible logLevels.
  */
-int MINLOG=MINLOGLEVEL;
-
-
-
 void LOG(LogLevel level, const char *origin, const char *format, ...)
 {
 
@@ -184,14 +253,14 @@ void LOG(LogLevel level, const char *origin, const char *format, ...)
 
   buf[0] = '\0';
   vsnprintf(buf, sizeof(buf), format, ap);
-  /*fprintf(stderr,getLogTextRaw(level,origin,buf));*/
+  /*fprintf(stderr, "%s", getLogTextRaw(level,origin,buf));*/
   if (strlen(buf)>0){
     LogEntry *le = LOG_NEW_ENTRY;
     LOG_APPEND(le);
     LOG_SETMESSAGE(le,buf);
     LOG_SETORIGIN(le,origin);
     le->level=level;
-    fprintf(stderr,getLogText(le));
+    fprintf(stderr, "%s", getLogText(le));
     if (loglist)
         (*loglist)(le);
   }
@@ -201,6 +270,9 @@ void LOG(LogLevel level, const char *origin, const char *format, ...)
 ChildProcess* FirstChild=NULL;
 ChildProcess* LastChild=NULL;
 
+/**
+ *
+ */
 void purgePipe(ChildProcess* cp, int pipe){
     char buf[512];
     int len;
@@ -230,6 +302,9 @@ void purgePipe(ChildProcess* cp, int pipe){
     }
 }
 
+/**
+ *
+ */
 void monitorChilds(void) {
 #ifndef WIN32
     ChildProcess* cp=FirstChild;
@@ -262,6 +337,9 @@ void monitorChilds(void) {
 #endif
 }
 
+/**
+ *
+ */
 void logPipe(ChildProcess *child, LogLevel level, int pipe){
 #ifndef WIN32
     char buf[1024];
@@ -281,6 +359,9 @@ void logPipe(ChildProcess *child, LogLevel level, int pipe){
 #endif
 }
 
+/**
+ *
+ */
 void logChildPipe(ChildProcess* child, LogLevel level, int flag){
     if (child->flag & flag & CHILD_STDOUT)
         logPipe(child,level,1);
@@ -288,6 +369,9 @@ void logChildPipe(ChildProcess* child, LogLevel level, int flag){
         logPipe(child,level,2);
 }
 
+/**
+ *
+ */
 ChildProcess* raiseChild(char* name, int flag){
 #ifndef WIN32
     ChildProcess* cp;
@@ -295,9 +379,7 @@ ChildProcess* raiseChild(char* name, int flag){
     int pipe_out[2];
     int pipe_err[2];
     int pid;
-    LogLevel deferror;
     char *args;
-    deferror=(flag & CHILD_SILENTFAIL)?LOG_INFO:LOG_ERROR;
     LOG(LOG_INFO,"common::raiseChild","Raising %s with flags %d",name,flag);
     flag=flag & (~CHILD_SILENTFAIL);
     if (flag & (~CHILD_TUBE)){
@@ -454,3 +536,4 @@ ChildProcess* raiseChild(char* name, int flag){
     return NULL;
 #endif
 }
+
