@@ -1,5 +1,5 @@
 const char * const rcsid_common_player_c =
-    "$Id$";
+    "$Id: player.c 12149 2009-08-20 02:11:28Z kbulgrien $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -22,24 +22,25 @@ const char * const rcsid_common_player_c =
     The author can be reached via e-mail to crossfire-devel@real-time.com
 */
 
+/**
+ * @file common/player.c
+ * Handles various player related functions.  This includes both things that
+ * operate on the player item, cpl structure, or various commands that the
+ * player issues.
+ *
+ * Most of the handling of commands from the client to server (see commands.c
+ * for server->client) is handled here.
+ *
+ * Most of the work for sending messages to the server is done here.  Again,
+ * most of these appear self explanatory.  Most send a bunch of commands like
+ * apply, examine, fire, run, etc.  This looks like it was done by Mark to
+ * remove the old keypress stupidity I used.
+ */
 
 #include <client.h>
 #include <external.h>
 #include <script.h>
 
-/* This file handles various player related functions.  This includes
- * both things that operate on the player item, cpl structure, or
- * various commands that the player issues.
- *
- *  This file does most of the handling of commands from the client to
- *  server (see commands.c for server->client)
- *
- *  does most of the work for sending messages to the server
- *   Again, most of these appear self explanatory.  Most send a bunch of
- *   commands like apply, examine, fire, run, etc.  This looks like it
- *   was done by Mark to remove the old keypress stupidity I used.
- */
-
 /* This translates the numeric direction id's into the actual direction
  * commands.  This lets us send the actual command (ie, 'north'), which
  * makes handling on the server side easier.
@@ -271,7 +272,8 @@ void command_take (const char *command, const char *cpnext)
 	send_command(command, cpl.count, 0);
     else {
 	if (cpl.container->inv == NULL)
-	    draw_info("There is nothing in the container to move", NDI_BLACK);
+	    draw_ext_info(NDI_BLACK, MSG_TYPE_CLIENT, MSG_TYPE_CLIENT_NOTICE,
+                "There is nothing in the container to move");
 	else
 	    cs_print_string(csocket.fd,"move %d %d %d", cpl.ob->tag,
 		cpl.container->inv->tag, cpl.count);
