@@ -3,7 +3,7 @@ void DoClient(ClientSocket *csocket);
 int init_connection(char *host, int port);
 void negotiate_connection(int sound);
 /* commands.c */
-void close_server_connection();
+void close_server_connection(void);
 void ReplyInfoCmd(uint8 *buf, int len);
 void SetupCmd(char *buf, int len);
 void ExtendedInfoSetCmd(char *data, int len);
@@ -39,6 +39,7 @@ void TickCmd(uint8 *data, int len);
 void PickupCmd(uint8 *data, int len);
 void FailureCmd(char *buf, int len);
 void AccountPlayersCmd(char *buf, int len);
+void free_all_race_class_info(Race_Class_Info *data, int num_entries);
 /* image.c */
 void init_common_cache_data(void);
 void requestface(int pnum, char *facename);
