@@ -1,5 +1,5 @@
 const char * const rcsid_common_script_c =
-    "$Id: script.c 13945 2010-10-01 02:16:15Z kbulgrien $";
+    "$Id: script.c 17543 2012-03-16 21:24:20Z ryo_saeba $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -119,6 +119,8 @@ const char * const rcsid_common_script_c =
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <sys/wait.h>
+/* for SIGHUP */
+#include <signal.h>
 #endif
 #include <ctype.h>
 
@@ -619,10 +621,11 @@ void script_process(fd_set *set) {
     }
 }
 
-void script_watch(const char *cmd, const uint8 *data, const int data_len, const enum CmdFormat format) {
+void script_watch(const char *cmd, const uint8 *data_initial, const int data_len, const enum CmdFormat format) {
     int i;
     int w;
     int l, len;
+    const uint8 *data;
 
     /* For each script... */
     for (i = 0; i < num_scripts; ++i) {
@@ -636,6 +639,7 @@ void script_watch(const char *cmd, const uint8 *data, const int data_len, const
             {
                 char buf[10240];
 
+                data = data_initial;
                 if (!len)
                     snprintf(buf, sizeof(buf), "watch %s\n", cmd);
                 else
@@ -850,28 +854,6 @@ void script_watch(const char *cmd, const uint8 *data, const int data_len, const
                                         len -= 4;
                                         break;
 
-                                    case CS_STAT_SKILLEXP_AGILITY:
-                                    case CS_STAT_SKILLEXP_PERSONAL:
-                                    case CS_STAT_SKILLEXP_MENTAL:
-                                    case CS_STAT_SKILLEXP_PHYSIQUE:
-                                    case CS_STAT_SKILLEXP_MAGIC:
-                                    case CS_STAT_SKILLEXP_WISDOM:
-                                        be += snprintf(buf+be, sizeof(buf)-be, " skillexp %d %d\n", c, GetInt_String(data));
-                                        data += 4;
-                                        len -= 4;
-                                        break;
-
-                                    case CS_STAT_SKILLEXP_AGLEVEL:
-                                    case CS_STAT_SKILLEXP_PELEVEL:
-                                    case CS_STAT_SKILLEXP_MELEVEL:
-                                    case CS_STAT_SKILLEXP_PHLEVEL:
-                                    case CS_STAT_SKILLEXP_MALEVEL:
-                                    case CS_STAT_SKILLEXP_WILEVEL:
-                                        be += snprintf(buf+be, sizeof(buf)-be, " skilllevel %d %d\n", c, GetShort_String(data));
-                                        data += 2;
-                                        len -= 2;
-                                        break;
-
                                     case CS_STAT_RANGE:
                                         {
                                             int rlen = *data;
