@@ -1,9 +1,9 @@
 const char * const rcsid_gtk2_config_c =
-    "$Id: config.c 14240 2011-01-12 06:31:21Z mwedel $";
+    "$Id: config.c 15868 2011-11-21 07:02:19Z mwedel $";
 /*
     Crossfire client, a client program for the crossfire program.
 
-    Copyright (C) 2005,2007 Mark Wedel & Crossfire Development Team
+    Copyright (C) 2005-2011 Mark Wedel & Crossfire Development Team
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -88,7 +88,7 @@ int scandir(const char *dir, struct dirent ***namelist,
 extern char window_xml_file[MAX_BUF];  /* Name of the .glade layout in use. */
 
 GtkWidget *config_window, *config_spinbutton_cwindow, *config_button_echo,
-    *config_button_fasttcp, *config_button_grad_color, *config_button_foodbeep,
+    *config_button_fasttcp, *config_button_timestamp, *config_button_grad_color, *config_button_foodbeep,
     *config_button_sound, *config_button_cache, *config_button_download,
     *config_button_fog, *config_spinbutton_iconscale, *config_spinbutton_mapscale,
     *config_spinbutton_mapwidth, *config_spinbutton_mapheight,
@@ -408,6 +408,23 @@ void load_defaults(void)
         want_config[CONFIG_MAPHEIGHT] = use_config[CONFIG_MAPHEIGHT];
     }
 
+#if !defined(HAVE_OPENGL)
+    if (want_config[CONFIG_DISPLAYMODE] == CFG_DM_OPENGL) {
+        want_config[CONFIG_DISPLAYMODE] = CFG_DM_PIXMAP;
+        LOG(LOG_ERROR, "config.c::load_defaults", "Display mode is set to OpenGL, but client "
+            "is not compiled with OpenGL support.  Reverting to pixmap mode.");
+    }
+#endif
+
+#if !defined(HAVE_SDL)
+    if (want_config[CONFIG_DISPLAYMODE] == CFG_DM_SDL) {
+        want_config[CONFIG_DISPLAYMODE] = CFG_DM_PIXMAP;
+        LOG(LOG_ERROR, "config.c::load_defaults", "Display mode is set to SDL, but client "
+            "is not compiled with SDL support.  Reverting to pixmap mode.");
+    }
+#endif
+
+
     /* Now copy over the values just loaded */
     for (i=0; i<CONFIG_NUMS; i++) {
         use_config[i] = want_config[i];
@@ -484,6 +501,8 @@ void config_init(GtkWidget *window_root)
         glade_xml_get_widget(xml_tree, "config_button_echo");
     config_button_fasttcp =
         glade_xml_get_widget(xml_tree, "config_button_fasttcp");
+    config_button_timestamp =
+        glade_xml_get_widget(xml_tree, "config_button_timestamp");
     config_button_grad_color =
         glade_xml_get_widget(xml_tree, "config_button_grad_color");
     config_button_foodbeep =
@@ -706,6 +725,9 @@ static void setup_config_window(void)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(config_button_fasttcp),
                                  want_config[CONFIG_FASTTCP]);
 
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(config_button_timestamp),
+                                 want_config[CONFIG_TIMESTAMP]);
+
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(config_button_grad_color),
                                  want_config[CONFIG_GRAD_COLOR]);
 
@@ -859,6 +881,7 @@ static void read_config_window(void)
 
     want_config[CONFIG_ECHO] = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(config_button_echo));
     want_config[CONFIG_FASTTCP] = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(config_button_fasttcp));
+    want_config[CONFIG_TIMESTAMP] = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(config_button_timestamp));
     want_config[CONFIG_GRAD_COLOR] = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(config_button_grad_color));
     want_config[CONFIG_FOODBEEP] = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(config_button_foodbeep));
     want_config[CONFIG_SOUND] = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(config_button_sound));
