@@ -1,5 +1,5 @@
 const char * const rcsid_gtk2_image_c =
-    "$Id: image.c 12884 2010-04-12 06:58:52Z mwedel $";
+    "$Id: image.c 12987 2010-04-27 03:50:58Z kbulgrien $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -132,7 +132,7 @@ static void create_icon_image(uint8 *data, PixmapInfo *pi, int pixmap_num)
     pi->icon_mask = NULL;
     if (rgba_to_gdkpixbuf(data, pi->icon_width, pi->icon_height,
                 (GdkPixbuf**)&pi->icon_image))
-                    LOG (LOG_ERROR,"gtk::create_icon_image","Unable to create scaled image, dest num = %d\n", pixmap_num);
+                    LOG (LOG_ERROR,"gtk-v2::create_icon_image","Unable to create scaled image, dest num = %d\n", pixmap_num);
 }
 
 /**
@@ -563,14 +563,14 @@ void get_map_image_size(int face, uint8 *w, uint8 *h)
  * the image to use when OpenGL mode is in effect.
  *
  */
-void init_cache_data(void)
+void init_image_cache_data(void)
 {
     int i;
     GtkStyle *style;
 #include "../../pixmaps/question.xpm"
 
 
-    LOG(LOG_INFO,"gtk::init_cache_data","Init Cache");
+    LOG(LOG_INFO,"gtk-v2::init_image_cache_data","Init Image Cache");
 
     style = gtk_widget_get_style(window_root);
     pixmaps[0] = malloc(sizeof(PixmapInfo));
