@@ -1,5 +1,5 @@
 const char * const rcsid_gtk2_inventory_c =
-    "$Id: inventory.c 11699 2009-05-22 03:46:22Z kbulgrien $";
+    "$Id: inventory.c 14240 2011-01-12 06:31:21Z mwedel $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -49,6 +49,7 @@ const char * const rcsid_gtk2_inventory_c =
 #include "../../pixmaps/nonmag.xpm"
 #include "../../pixmaps/skull.xpm"
 #include "../../pixmaps/unlock.xpm"
+#include "../../pixmaps/unidentified.xpm"
 
 GtkWidget *inv_notebook;
 GtkWidget *treeview_look;
@@ -86,7 +87,7 @@ static GtkStyle    *inv_styles[Style_Last];
  * to know about the different inventory notebooks in a module fashion -
  * instead of hardcoding values, they can be held in the array.
  */
-#define NUM_INV_LISTS   10
+#define NUM_INV_LISTS   11
 #define INV_SHOW_ITEM   0x1
 #define INV_SHOW_COLOR  0x2
 
@@ -123,6 +124,7 @@ static int show_magical(item *it)   { return (it->magical?INV_SHOW_ITEM:0); }
 static int show_nonmagical(item *it){ return (it->magical?0:INV_SHOW_ITEM); }
 static int show_locked(item *it)    { return (it->locked?(INV_SHOW_ITEM|INV_SHOW_COLOR):0); }
 static int show_unlocked(item *it)  { return (it->locked?0:(INV_SHOW_ITEM|INV_SHOW_COLOR)); }
+static int show_unidentified(item *it)  { return ((it->flagsval&F_UNIDENTIFIED)?INV_SHOW_ITEM:0); }
 
 Notebook_Info   inv_notebooks[NUM_INV_LISTS] = {
 {"all", "All Items", all_xpm, show_all, INV_TREE},
@@ -134,6 +136,7 @@ Notebook_Info   inv_notebooks[NUM_INV_LISTS] = {
 {"nonmagical", "Nonmagical items", nonmag_xpm, show_nonmagical, INV_TREE},
 {"locked", "Inventory locked items", lock_xpm, show_locked, INV_TREE},
 {"unlocked", "Inventory unlocked items",unlock_xpm, show_unlocked, INV_TREE},
+{"unidentified", "Inventory unidentified items", unidentified_xpm, show_unidentified, INV_TREE},
 {"icons", "Quick icon view", NULL, show_all, INV_TABLE}
 };
 
@@ -251,7 +254,7 @@ gboolean list_selection_func (
     /* Get the current event so we can know if shift is pressed */
     event = (GdkEventButton*)gtk_get_current_event();
     if (!event) {
-        LOG(LOG_ERROR,"inventory.c:list_selection_func", "Unable to get event structure\n");
+        LOG(LOG_ERROR,"inventory.c::list_selection_func", "Unable to get event structure\n");
         return FALSE;
     }
 
@@ -261,7 +264,7 @@ gboolean list_selection_func (
         gtk_tree_model_get(model, &iter, LIST_OBJECT, &tmp, -1);
 
         if (!tmp) {
-            LOG(LOG_ERROR,"inventory.c:list_selection_func", "Unable to get item structure\n");
+            LOG(LOG_ERROR,"inventory.c::list_selection_func", "Unable to get item structure\n");
             return FALSE;
         }
         list_item_action(event, tmp);
@@ -427,7 +430,7 @@ void inventory_init(GtkWidget *window_root)
     int i;
     GladeXML *xml_tree;
 
-    inventory_get_styles();
+    /*inventory_get_styles();*/
 
     xml_tree = glade_get_widget_tree(GTK_WIDGET(window_root));
 
@@ -530,7 +533,7 @@ void inventory_init(GtkWidget *window_root)
 
     /* If all the data is set up properly, these should match */
     if (num_inv_notebook_pages != NUM_INV_LISTS) {
-        LOG(LOG_ERROR,"inventory.c:inventory_init",
+        LOG(LOG_ERROR,"inventory.c::inventory_init",
             "num_inv_notebook_pages (%d) does not match NUM_INV_LISTS(%d)\n",
             num_inv_notebook_pages, NUM_INV_LISTS);
     }
