@@ -1,5 +1,5 @@
 const char * const rcsid_gtk2_keys_c =
-    "$Id: keys.c 12875 2010-04-09 07:04:28Z mwedel $";
+    "$Id: keys.c 13647 2010-08-19 04:11:23Z kbulgrien $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -229,7 +229,7 @@ static void parse_keybind_line(char *buf, int line, int standard)
 
     if (buf[0]=='#' || buf[0]=='\n') return;
     if ((cpnext = strchr(buf,' '))==NULL) {
-        LOG(LOG_WARNING,"gtk::parse_keybind_line","Line %d (%s) corrupted in keybinding file.", line,buf);
+        LOG(LOG_WARNING,"gtk-v2::parse_keybind_line","Line %d (%s) corrupted in keybinding file.", line,buf);
         return;
     }
     /* Special keybinding line */
@@ -238,20 +238,20 @@ static void parse_keybind_line(char *buf, int line, int standard)
         while (*cpnext == ' ') ++cpnext;
         cp = strchr(cpnext, ' ');
         if (!cp) {
-            LOG(LOG_WARNING,"gtk::parse_keybind_line","Line %d (%s) corrupted in keybinding file.", line,buf);
+            LOG(LOG_WARNING,"gtk-v2::parse_keybind_line","Line %d (%s) corrupted in keybinding file.", line,buf);
             return;
         }
         *cp++ = 0;  /* Null terminate it */
         cp1 = strchr(cp, ' ');
         if (!cp1) {
-            LOG(LOG_WARNING,"gtk::parse_keybind_line","Line %d (%s) corrupted in keybinding file.", line,buf);
+            LOG(LOG_WARNING,"gtk-v2::parse_keybind_line","Line %d (%s) corrupted in keybinding file.", line,buf);
             return;
         }
         *cp1 ++ = 0;/* Null terminate it */
         keysym = gdk_keyval_from_name(cp);
         /* As of now, all these keys must have keysyms */
         if (keysym == 0) {
-            LOG(LOG_WARNING,"gtk::parse_keybind_line","Could not convert %s into keysym", cp);
+            LOG(LOG_WARNING,"gtk-v2::parse_keybind_line","Could not convert %s into keysym", cp);
             return;
         }
         if (!strcmp(cpnext,"commandkey")) {
@@ -309,19 +309,19 @@ static void parse_keybind_line(char *buf, int line, int standard)
         *cpnext++ = '\0';
         keysym = gdk_keyval_from_name(buf);
         if (!keysym) {
-            LOG(LOG_WARNING,"gtk::parse_keybind_line","Unable to convert line %d (%s) into keysym", line, cp);
+            LOG(LOG_WARNING,"gtk-v2::parse_keybind_line","Unable to convert line %d (%s) into keysym", line, cp);
             return;
         }
         cp = cpnext;
         if ((cpnext = strchr(cp,' '))==NULL) {
-            LOG(LOG_WARNING,"gtk::parse_keybind_line","Line %d (%s) corrupted in keybinding file.", line, cp);
+            LOG(LOG_WARNING,"gtk-v2::parse_keybind_line","Line %d (%s) corrupted in keybinding file.", line, cp);
             return;
         }
         *cpnext++ = '\0';
 
         cp = cpnext;
         if ((cpnext = strchr(cp,' '))==NULL) {
-            LOG(LOG_WARNING,"gtk::parse_keybind_line","Line %d (%s) corrupted in keybinding file.", line, cp);
+            LOG(LOG_WARNING,"gtk-v2::parse_keybind_line","Line %d (%s) corrupted in keybinding file.", line, cp);
             return;
         }
         *cpnext++ = '\0';
@@ -354,7 +354,7 @@ static void parse_keybind_line(char *buf, int line, int standard)
                     flags |= KEYF_STANDARD;
                     break;
                 default:
-                    LOG(LOG_WARNING,"gtk::parse_keybind_line","Unknown flag (%c) line %d in key binding file",
+                    LOG(LOG_WARNING,"gtk-v2::parse_keybind_line","Unknown flag (%c) line %d in key binding file",
                             *cp, line);
             }
             cp++;
@@ -364,7 +364,7 @@ static void parse_keybind_line(char *buf, int line, int standard)
         cpnext[strlen(cpnext)-1]='\0';
         if (strlen(cpnext)>(sizeof(bind_buf)-1)){
             cpnext[sizeof(bind_buf)-1]='\0';
-            LOG(LOG_WARNING,"gtk::parse_keybind_line","Command too long! Truncated.");
+            LOG(LOG_WARNING,"gtk-v2::parse_keybind_line","Command too long! Truncated.");
         }
 
         insert_key(keysym, flags | standard, cpnext);
@@ -463,6 +463,7 @@ void keys_init(GtkWidget *window_root)
         sprintf(buf,"%s/.crossfire/keys", getenv("HOME"));
 #else
     snprintf(buf, sizeof(buf), "%s/.crossfire/keys", getenv("HOME"));
+    CONVERT_FILESPEC_TO_OS_FORMAT(buf);
 #endif
 
     xml_tree = glade_get_widget_tree(GTK_WIDGET(window_root));
@@ -472,8 +473,8 @@ void keys_init(GtkWidget *window_root)
     entry_commands = glade_xml_get_widget(xml_tree, "entry_commands");
     spinbutton_count = glade_xml_get_widget(xml_tree, "spinbutton_count");
 
-    g_signal_connect ((gpointer) entry_commands, "activate",
-        G_CALLBACK (on_entry_commands_activate), NULL);
+    g_signal_connect((gpointer) entry_commands, "activate",
+        G_CALLBACK(on_entry_commands_activate), NULL);
 
     keybinding_window = glade_xml_get_widget(dialog_xml, "keybinding_window");
     xml_tree = glade_get_widget_tree(GTK_WIDGET(keybinding_window));
@@ -501,22 +502,24 @@ void keys_init(GtkWidget *window_root)
     keybinding_button_bind =
         glade_xml_get_widget(xml_tree, "keybinding_button_bind");
 
-    g_signal_connect ((gpointer) keybinding_entry_key, "key_press_event",
-        G_CALLBACK (on_keybinding_entry_key_key_press_event), NULL);
-    g_signal_connect ((gpointer) keybinding_button_remove, "clicked",
-        G_CALLBACK (on_keybinding_button_remove_clicked), NULL);
-    g_signal_connect ((gpointer) keybinding_button_update, "clicked",
-        G_CALLBACK (on_keybinding_button_update_clicked), NULL);
-    g_signal_connect ((gpointer) keybinding_button_bind, "clicked",
-        G_CALLBACK (on_keybinding_button_bind_clicked), NULL);
+    g_signal_connect((gpointer) keybinding_window, "delete_event",
+        G_CALLBACK(gtk_widget_hide_on_delete), NULL);
+    g_signal_connect((gpointer) keybinding_entry_key, "key_press_event",
+        G_CALLBACK(on_keybinding_entry_key_key_press_event), NULL);
+    g_signal_connect((gpointer) keybinding_button_remove, "clicked",
+        G_CALLBACK(on_keybinding_button_remove_clicked), NULL);
+    g_signal_connect((gpointer) keybinding_button_update, "clicked",
+        G_CALLBACK(on_keybinding_button_update_clicked), NULL);
+    g_signal_connect((gpointer) keybinding_button_bind, "clicked",
+        G_CALLBACK(on_keybinding_button_bind_clicked), NULL);
 
     widget = glade_xml_get_widget(xml_tree, "keybinding_button_clear");
-    g_signal_connect ((gpointer) widget, "clicked",
-        G_CALLBACK (on_keybinding_button_clear_clicked), NULL);
+    g_signal_connect((gpointer) widget, "clicked",
+        G_CALLBACK(on_keybinding_button_clear_clicked), NULL);
 
     widget = glade_xml_get_widget(xml_tree, "keybinding_button_close");
-    g_signal_connect ((gpointer) widget, "clicked",
-        G_CALLBACK (on_keybinding_button_close_clicked), NULL);
+    g_signal_connect((gpointer) widget, "clicked",
+        G_CALLBACK(on_keybinding_button_close_clicked), NULL);
 
     gtk_widget_set_sensitive(keybinding_button_remove, FALSE);
     gtk_widget_set_sensitive(keybinding_button_update, FALSE);
@@ -565,7 +568,7 @@ void keys_init(GtkWidget *window_root)
                                              GTK_SORT_ASCENDING);
 
     if ((fp=fopen(buf,"r"))==NULL) {
-        LOG(LOG_INFO,"gtk::init_keys","Could not open ~/.crossfire/keys, trying to load global bindings");
+        LOG(LOG_INFO,"gtk-v2::init_keys","Could not open ~/.crossfire/keys, trying to load global bindings");
         if (client_libdir==NULL) {
             init_default_keybindings();
             return;
@@ -1102,10 +1105,11 @@ static void save_keys(void)
         sprintf( buf,"%s/.crossfire/keys", getenv("HOME") );
 #else
     snprintf(buf, sizeof(buf), "%s/.crossfire/keys", getenv("HOME"));
+    CONVERT_FILESPEC_TO_OS_FORMAT(buf);
 #endif
 
     if (make_path_to_file(buf)==-1) {
-        LOG(LOG_WARNING,"gtk::save_keys","Could not create %s", buf);
+        LOG(LOG_WARNING,"gtk-v2::save_keys","Could not create %s", buf);
         return;
     }
     if ((fp=fopen(buf,"w"))==NULL) {
@@ -1337,7 +1341,7 @@ void unbind_key(const char *params)
                         goto unbinded;
                     }
                 }
-                LOG(LOG_ERROR, "gtk:unbind_key",
+                LOG(LOG_ERROR, "gtk-v2::unbind_key",
                     "found number entry, but could not find actual key");
             }
         }
@@ -1507,7 +1511,7 @@ void keyfunc(GtkWidget *widget, GdkEventKey *event, GtkWidget *window) {
                     break;
 
                 default:
-                    LOG(LOG_ERROR, "gtk:keyfunc",
+                    LOG(LOG_ERROR, "gtk-v2::keyfunc",
                         "Unknown input state: %d", cpl.input_state);
             }
         }
@@ -1862,7 +1866,7 @@ on_keybinding_button_remove_clicked    (GtkButton       *button,
     int onkey;
 
     if (!gtk_tree_selection_get_selected(keybinding_selection, &model, &iter)) {
-        LOG(LOG_ERROR, "keys.c:on_keybinding_button_remove_clicked",
+        LOG(LOG_ERROR, "keys.c::on_keybinding_button_remove_clicked",
             "Function called with nothing selected\n");
         return;
     }
@@ -1891,7 +1895,7 @@ on_keybinding_button_remove_clicked    (GtkButton       *button,
             }
         }
     }
-    LOG(LOG_ERROR, "keys.c:on_keybinding_button_remove_clicked",
+    LOG(LOG_ERROR, "keys.c::on_keybinding_button_remove_clicked",
         "Unable to find matching key entry\n");
 
 unbinded:
@@ -1962,7 +1966,7 @@ static void keybinding_get_data(uint32 *keysym, uint8 *flags, const char **comma
     *keysym = gdk_keyval_from_name(
         gtk_entry_get_text(GTK_ENTRY(keybinding_entry_key)));
     if (*keysym == GDK_VoidSymbol) {
-        LOG(LOG_ERROR, "keys.c:keybinding_get_data",
+        LOG(LOG_ERROR, "keys.c::keybinding_get_data",
             "Cannot get valid keysym from selection");
     }
 }
@@ -2018,7 +2022,7 @@ on_keybinding_button_update_clicked    (GtkButton       *button,
         gtk_tree_model_get(model, &iter, KLIST_KEY_ENTRY, &entry, -1);
 
         if (!entry) {
-            LOG(LOG_ERROR, "keys.c:on_keybinding_button_update_clicked",
+            LOG(LOG_ERROR, "keys.c::on_keybinding_button_update_clicked",
                 "Unable to get key_entry structure\n");
             return;
         }
@@ -2028,7 +2032,7 @@ on_keybinding_button_update_clicked    (GtkButton       *button,
         update_keybinding_list();
         save_keys();
     } else {
-        LOG(LOG_ERROR, "keys.c:on_keybinding_button_update_clicked",
+        LOG(LOG_ERROR, "keys.c::on_keybinding_button_update_clicked",
             "Nothing selected to update\n");
     }
 }
@@ -2076,7 +2080,7 @@ gboolean keybinding_selection_func (
         gtk_tree_model_get(model, &iter, KLIST_KEY_ENTRY, &entry, -1);
 
         if (!entry) {
-            LOG(LOG_ERROR, "keys.c:keybinding_selection_func",
+            LOG(LOG_ERROR, "keys.c::keybinding_selection_func",
                 "Unable to get key_entry structure\n");
             return FALSE;
         }
