@@ -1,11 +1,11 @@
 /*
  * char *rcsid_gtk2_main_h =
- *   "$Id: main.h 12878 2010-04-09 09:27:27Z kbulgrien $";
+ *   "$Id: main.h 14247 2011-01-24 05:21:30Z mwedel $";
  */
 /*
     Crossfire client, a client program for the crossfire program.
 
-    Copyright (C) 2005,2010 Mark Wedel & Crossfire Development Team
+    Copyright (C) 2005,2010,2011 Mark Wedel & Crossfire Development Team
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,8 +37,8 @@ extern GladeXML *dialog_xml, *window_xml;
 #define DEFAULT_IMAGE_SIZE      32
 extern int map_image_size, map_image_half_size, image_size;
 
-#define XML_PATH_DEFAULT PACKAGE_DATA_DIR "/" PACKAGE "/glade-gtk2/"
-#define WINDOW_XML_FILENAME "gtk-v2.glade"
+#define XML_PATH_DEFAULT CF_DATADIR "/glade-gtk2/"
+#define WINDOW_XML_FILENAME "gtk-v1.glade"
 #define DIALOG_XML_FILENAME "dialogs.glade"
 extern char window_xml_file[];
 
@@ -46,5 +46,6 @@ extern char window_xml_file[];
 
 extern gint csocket_fd;
 
+extern char account_password[256];
 /* gtk2proto.h depends on this - so may as well just include it here */
 #include "info.h"
