@@ -1,5 +1,5 @@
 const char * const rcsid_gtk2_map_c =
-    "$Id: map.c 13982 2010-10-09 22:41:04Z anmaster $";
+    "$Id: map.c 14690 2011-06-23 20:26:31Z ryo_saeba $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -355,7 +355,7 @@ void drawsmooth (int mx,int my,int layer,int picx,int picy){
             draw_pixmap(
                 weightC*map_image_size, map_image_size,
                 picx, picy,
-                picx-weightC*map_image_size, picy-map_image_size,
+                picx-weightC*map_image_size, picy+map_image_size,
                 pixmaps[smoothface]->map_mask, pixmaps[smoothface]->map_image, map_image_size, map_image_size);
         }
     } /* while there's some smooth to do */
