@@ -1,5 +1,5 @@
 const char * const rcsid_gtk2_metaserver_c =
-    "$Id: metaserver.c 12875 2010-04-09 07:04:28Z mwedel $";
+    "$Id: metaserver.c 13042 2010-04-30 01:02:01Z kbulgrien $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -77,7 +77,9 @@ gboolean metaserver_selection_func (
 }
 
 /**
- * Constructs the metaserver dialog and handles metaserver selection.
+ * Constructs the metaserver dialog and handles metaserver selection.  If the
+ * player has a servers.cache file in their .crossfire folder, the cached
+ * server list is added to the contents of the metaserver dialog.
  */
 void get_metaserver(void)
 {
@@ -250,62 +252,17 @@ void get_metaserver(void)
 }
 
 /**
- * Establish a connection with the server when pressing the connect button.
+ * Establish a connection to a server when a server DNS name or IP address is
+ * specified.   Either a DNS name or IP address may be given, but if both are
+ * supplied the IP address is used.  To connect on a non-standard port number,
+ * a colon and the port number is appended to the DNS name.  Update the server
+ * cache if the connection attempt succeeds.
  *
- * @param button
- * @param user_data
- */
-void
-on_metaserver_select_clicked           (GtkButton       *button,
-                                        gpointer         user_data)
-{
-    GtkTreeModel    *model;
-    GtkTreeIter iter;
-    char    *name=NULL, *ip=NULL, buf[256], *metaserver_txt;
-
-    metaserver_txt = (char*)gtk_entry_get_text(GTK_ENTRY(metaserver_entry));
-    if (gtk_tree_selection_get_selected (metaserver_selection, &model, &iter)) {
-        gtk_tree_model_get(model, &iter, LIST_HOSTNAME, &name, LIST_IPADDR, &ip, -1);
-
-    } else if (*metaserver_txt == '\0') {
-
-        /* This can happen if user blanks out server name text field then hits
-         * the connect button.
-         */
-        gtk_label_set_text(GTK_LABEL(metaserver_status), "Error - nothing selected!\n");
-        gtk_widget_set_sensitive(metaserver_button, FALSE);
-        return;
-    } else {
-        /* This shouldn't happen because the button should not be pressable
-         * until the user selects something
-         */
-        gtk_label_set_text(GTK_LABEL(metaserver_status), "Error - nothing selected!\n");
-    }
-    if (!name) name = metaserver_txt;
-
-    snprintf(buf, 255, "Trying to connect to %s", name);
-
-    gtk_label_set_text(GTK_LABEL(metaserver_status), buf);
-
-    csocket.fd=init_connection(ip?ip:name, use_config[CONFIG_PORT]);
-    if (csocket.fd==-1) {
-        snprintf(buf, 255, "Unable to connect to %s!", name);
-        gtk_label_set_text(GTK_LABEL(metaserver_status), buf);
-    } else {
-        snprintf(buf, 255, "Connected to %s!", name);
-        gtk_label_set_text(GTK_LABEL(metaserver_status), buf);
-        gtk_main_quit();
-        cpl.input_state = Playing;
-    }
-}
-
-/**
- * Establish a connection to a server when the server name was entered.  Either
- * a DNS name or IP address may be specified, but if both are supplied, use the
- * IP address.
- *
- * @param name The DNS name of a server to connect to.
- * @param ip An IP address of a server to connect to.
+ * @param name The DNS name of a server to connect to.  If the server operates
+ *             on a non-standard port, a colon and the port number is appended
+ *             to the DNS name.  For example:  localhost:8000
+ * @param ip   An IP address of a server to connect to.  If specified, the IP
+ *             address is used instead of the DNS name.
  */
 static void metaserver_connect_to(const char *name, const char *ip)
 {
@@ -329,12 +286,50 @@ static void metaserver_connect_to(const char *name, const char *ip)
         gtk_label_set_text(GTK_LABEL(metaserver_status), buf);
     } else {
         snprintf(buf, 255, "Connected to %s!", name);
+        metaserver_update_cache(name, ip ? ip : name);
         gtk_label_set_text(GTK_LABEL(metaserver_status), buf);
         gtk_main_quit();
         cpl.input_state = Playing;
     }
 }
 
+/**
+ * Establish a connection with the server when pressing the connect button.
+ *
+ * @param button
+ * @param user_data
+ */
+void
+on_metaserver_select_clicked           (GtkButton       *button,
+                                        gpointer         user_data)
+{
+    GtkTreeModel    *model;
+    GtkTreeIter iter;
+    char    *name=NULL, *ip=NULL, *metaserver_txt;
+
+    metaserver_txt = (char*)gtk_entry_get_text(GTK_ENTRY(metaserver_entry));
+    if (gtk_tree_selection_get_selected (metaserver_selection, &model, &iter)) {
+        gtk_tree_model_get(model, &iter, LIST_HOSTNAME, &name, LIST_IPADDR, &ip, -1);
+
+    } else if (*metaserver_txt == '\0') {
+
+        /* This can happen if user blanks out server name text field then hits
+         * the connect button.
+         */
+        gtk_label_set_text(GTK_LABEL(metaserver_status), "Error - nothing selected!\n");
+        gtk_widget_set_sensitive(metaserver_button, FALSE);
+        return;
+    } else {
+        /* This shouldn't happen because the button should not be pressable
+         * until the user selects something
+         */
+        gtk_label_set_text(GTK_LABEL(metaserver_status), "Error - nothing selected!\n");
+    }
+    if (!name) name = metaserver_txt;
+
+    metaserver_connect_to(name, ip);
+}
+
 /**
  * Selects and attempts a connection to a server if the player activates one of
  * the server entries.
