@@ -1,5 +1,5 @@
 const char * const rcsid_gtk_sdl_c =
-    "$Id: sdl.c 9200 2008-06-01 17:12:43Z anmaster $";
+    "$Id: sdl.c 13982 2010-10-09 22:41:04Z anmaster $";
 
 /*
     Crossfire client, a client program for the crossfire program.
@@ -269,7 +269,7 @@ void init_SDL( GtkWidget* sdl_window, int just_lightmap)
 
         if( SDL_Init( SDL_INIT_VIDEO) < 0)
         {
-            LOG(LOG_CRITICAL,"gtk::init_SDL", "Could not initialize SDL: %s", SDL_GetError());
+            LOG(LOG_CRITICAL,"gtk-v2::init_SDL", "Could not initialize SDL: %s", SDL_GetError());
             gtk_main_quit();
         }
 
@@ -358,21 +358,25 @@ void init_SDL( GtkWidget* sdl_window, int just_lightmap)
  * Note - profile shows this is a very costly function - of a small run,
  * 77% of the time of the cpu time for the client was in this function.
  *
- * @param tl
- * @param tr
- * @param bl
- * @param br
- * @param width
- * @param height
- * @param startx Coordinate of the top left corner.
- * @param starty Coordinate of the top left corner.
- * @param destx Coordinate of top left corner in destination map.
- * @param desty Coordinate of top left corner in destination map.
+ * @param tl     color
+ * @param tr     color
+ * @param bl     color
+ * @param br     color
+ * @param width  color square size
+ * @param height color square size
+ * @param startx Top left corner of the interpolation region.
+ * @param starty Top left corner of the interpolation region.
+ * @param endx   Bottom right corner of the interpolation region.
+ * @param endy   Bottom right corner of the interpolation region.
+ * @param destx  Coordinate of top left corner in destination map, or where in
+ *               the lightmap to save the result.
+ * @param desty  Coordinate of top left corner in destination map, or where in
+ *               the lightmap to save the result.
  */
-void drawquarterlightmap_sdl(int tl, int tr, int bl, int br,                /*colors*/
-                             int width, int height,                         /*color square size*/
-                             int startx, int starty, int endx, int endy,    /*interpolation region*/
-                             int destx, int desty){                         /*where in lightmap to save result*/
+void drawquarterlightmap_sdl(int tl, int tr, int bl, int br,
+                             int width, int height,
+                             int startx, int starty, int endx, int endy,
+                             int destx, int desty){
         int x,y;
         int top,bottom,val;
         for (x=startx;x<endx;x++){
@@ -689,7 +693,7 @@ static void drawsmooth_sdl (int mx,int my,int layer,SDL_Rect dst){
     int partdone[8]={0,0,0,0,0,0,0,0};
     int slevels[8];
     int sfaces[8];
-    int i,lowest,weight,weightC;
+    int i,weight,weightC;
     int emx,emy;
     int smoothface;
     int hasFace = 0;
@@ -723,9 +727,8 @@ static void drawsmooth_sdl (int mx,int my,int layer,SDL_Rect dst){
      * there are at most 8 different levels. so... let's check 8 times
      * for the lowest one (we draw from botto to top!).
      */
-    lowest=-1;
     while (1){
-        lowest = -1;
+        int lowest = -1;
         for (i=0;i<8;i++){
             if ( (slevels[i]>0) && (!partdone[i]) &&
                 ((lowest<0) || (slevels[i]<slevels[lowest]))
@@ -1050,7 +1053,7 @@ void sdl_gen_map(int redraw) {
         /* I care about performance for 'long' updates, so put the check in to make
          * these a little more noticable */
         if ((elapsed1 + elapsed2)>10000)
-            LOG(LOG_INFO,"gtk::sdl_gen_map","gen took %7ld, flip took %7ld, total = %7ld",
+            LOG(LOG_INFO,"gtk-v2::sdl_gen_map","gen took %7ld, flip took %7ld, total = %7ld",
                     elapsed1, elapsed2, elapsed1 + elapsed2);
     }
 } /* sdl_gen_map function */
