@@ -1,5 +1,5 @@
 const char * const rcsid_gtk2_stats_c =
-    "$Id: stats.c 12917 2010-04-17 17:15:18Z kbulgrien $";
+    "$Id: stats.c 14240 2011-01-12 06:31:21Z mwedel $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -51,9 +51,9 @@ static const char * const stat_bar_names[MAX_STAT_BARS] = {
     "hp", "sp", "grace", "food", "exp"
 };
 
-GtkWidget *stat_current[MAX_STAT_BARS];
-GtkWidget *stat_max[MAX_STAT_BARS];
-GtkWidget *stat_bar[MAX_STAT_BARS];
+static GtkWidget *stat_current[MAX_STAT_BARS];
+static GtkWidget *stat_max[MAX_STAT_BARS];
+static GtkWidget *stat_bar[MAX_STAT_BARS];
 
 #define STYLE_NORMAL        0
 #define STYLE_LOW           1
@@ -255,7 +255,7 @@ void stats_init(GtkWidget *window_root)
             y++;
         }
     }
-    stats_get_styles();
+    /*stats_get_styles();*/
 }
 
 
