@@ -1,5 +1,5 @@
 static char *rcsid_sound_src_alsa9_c =
-    "$Id: alsa9.c 12153 2009-08-20 23:31:20Z kbulgrien $";
+    "$Id: alsa9.c 13995 2010-10-14 04:01:47Z kbulgrien $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -70,9 +70,11 @@ static char *rcsid_sound_src_alsa9_c =
 #include <ctype.h>
 #include <errno.h>
 
-#include "shared/newclient.h"
-#include "soundsdef.h"
-
+#include "newclient.h"
+#include "client-types.h"
+#include "def_sounds.h"
+#include "sndproto.h"
+#include "common.h"
 
 #include <alsa/asoundlib.h>
 #include <alsa/pcm_plugin.h>
@@ -86,9 +88,6 @@ int sndbuf_pos=0;
 #define ALSA9_ERROR(str,err) { \
 		fprintf(stderr,"ALSA9 Error: %s %s\n",str,snd_strerror(err)); }
 
-#define CONFIG_FILE "/.crossfire/sndconfig"
-
-
 #define SOUND_DECREASE 0.1
 
 /* mixer variables */
@@ -98,16 +97,7 @@ int first_free_buffer=0; /* So we know when to stop playing sounds */
 
 int soundfd=0;
 
-/* sound device parameters */
-int stereo=0,sample_size=0,frequency=0,sign=0,zerolevel=0;
-
-struct sound_settings{
-    int stereo, bit8, sign, frequency, buffers, buflen,simultaneously;
-    const char *audiodev;
-} settings={0,1, 0, 8000,200,2048,4,AUDIODEV};
-
-#include "common.c"
-
+sound_settings settings = { 0, 1, 0, 8000, 200, 2048, 4, AUDIODEV };
 
 snd_pcm_hw_params_t *params;
 static snd_pcm_uframes_t chunk_size = 0;
@@ -115,13 +105,24 @@ int err = 0;
 
 void alsa_audio_close(void) { snd_pcm_close(handle); }
 
+/**
+ * Initialize the Alsa9 sound system.
+ *
+ * @return Zero if audio initialized successfully, otherwise -1.
+ */
 int init_audio(void) {
     snd_pcm_sw_params_t *sw_params;
     unsigned int format;
 
-    printf("cfsndserv compiled for ALSA9 sound system\n");
+    printf("cfsndserv for the ALSA9 sound system\n");
+    printf("supports sound effects only (no background music).\n");
     fflush(stdout);
 
+#ifdef SOUND_DEBUG
+    fprintf(stderr, "init_audio: ALSA9\n");
+    fflush(stderr);
+#endif
+
     /* open the PCM device */
     if ((err = snd_pcm_open(&handle,AUDIODEV,SND_PCM_STREAM_PLAYBACK,0)) <0) {
 	ALSA9_ERROR("init_audio(): ",err);
@@ -251,16 +252,27 @@ void alsa_recover(int e) {
 
 
 
-/* Does the actual task of writing the data to the socket.
- * The ALSA write logic is a bit odd, in that the count you pass in
- * is not the number of bytes you are writing, but the number of
- * samples you are writing.  Thus, if you have stereo with 1 byte/channel,
- * you'd divide the number by 2.  If you have 16 bit audio with stereo,
- * you'd divide the number by 4.
+/**
+ * Play a sound using the Alsa9 sound system.
+ *
+ * Does the actual task of writing the data to the socket.  The ALSA write
+ * logic is a bit odd, in that the count you pass in is not the number of
+ * bytes you are writing, but the number of samples you are writing.  Thus, if
+ * you have stereo with 1 byte/channel, you'd divide the number by 2.  If you
+ * have 16 bit audio with stereo, you'd divide the number by 4.
+ *
+ * @param buffer
+ * @param off
+ * @return
  */
 int audio_play(int buffer, int off) {
     int count = (settings.buflen - off) / sample_size;
 
+#ifdef SOUND_DEBUG
+    fprintf(stderr, "audio_play: ALSA9\n");
+    fflush(stderr);
+#endif
+
     if (count > chunk_size) count=chunk_size;
 
 #ifdef SOUND_DEBUG_WRITES
@@ -279,12 +291,6 @@ int audio_play(int buffer, int off) {
     }
 }
 
-
-
-
-
-
-
 /* Plays sound 'soundnum'.  soundtype is 0 for normal sounds, 1 for
  * spell_sounds.  This might get extended in the future.  x,y are offset
  * (assumed from player) to play sound.  This information is used to
@@ -301,6 +307,11 @@ void play_sound(int soundnum, int soundtype, int x, int y)
     unsigned left_ratio,right_ratio;
     double dist;
 
+#ifdef SOUND_DEBUG
+    fprintf(stderr, "play_sound: ALSA9\n");
+    fflush(stderr);
+#endif
+
     buf=current_buffer;
     if (buf>=settings.buffers) buf=1;
 
@@ -458,6 +469,22 @@ void play_sound(int soundnum, int soundtype, int x, int y)
 
 }
 
+/**
+ * Stub for playing music with the Alsa 9 sound system.
+ *
+ * @param name A name of a song to play that does not include anything like
+ *             path or file extensions.  It is up to this function to map the
+ *             name to a file.
+ */
+void play_music(const char *name) {
+
+#ifdef SOUND_DEBUG
+    fprintf(stderr, "play_music: no music support for this sound system.\n");
+    fflush(stderr);
+#endif
+
+    return;
+}
 
 int main(int argc, char *argv[])
 {
@@ -468,7 +495,6 @@ int main(int argc, char *argv[])
     struct timeval timeout;
 
     printf ("%s\n",rcsid_sound_src_alsa9_c);
-
     fflush(stdout);
 
     if (read_settings()) write_settings();
@@ -532,7 +558,7 @@ int main(int argc, char *argv[])
 		}
 		if (inbuf[inbuf_pos]=='\n'){
 		    inbuf[inbuf_pos++]=0;
-		    SoundCmd((unsigned char *)inbuf,inbuf_pos);
+		    StdinCmd((char *)inbuf, inbuf_pos);
 		    inbuf_pos=0;
 		}
 		else {
