@@ -16,13 +16,21 @@ if ($#ARGV!=2) {
 open(INFILE, "<$ARGV[0]") || die("can not open $ARGV[0]\n");
 open(OUTFILE, ">$ARGV[1]") || die("can not open $ARGV[1]\n");
 
-print OUTFILE "char *$ARGV[2]\[\] = {\n";
-while (<INFILE>) {
-	chomp;
-	s/\"/\\\"/g;
-	print OUTFILE "\"$_\\n\",\n";
+$LINES += tr/\n/\n/ while sysread(INFILE, $_, 2 ** 16);
+
+if ( $ARGV[1] =~ m/.h$/) {
+    print OUTFILE "extern char *$ARGV[2]\[" . $LINES . "\];\n";
+} else {
+    seek(INFILE, 0, 0);
+    print OUTFILE "char *$ARGV[2]\[" . $LINES . "\] = {\n";
+    while (<INFILE>) {
+        chomp;
+        s/\"/\\\"/g;
+        print OUTFILE "\"$_\\n\",\n";
+    }
+    print OUTFILE "};\n";
 }
-print OUTFILE "};\n";
-print "$. lines processed\n";
+print $LINES . " lines processed\n";
 close(INFILE);
 close(OUTFILE);
+
